@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bulletin_board_ui.c,v 1.132 2004/01/22 07:43:25 fuyu Exp $
+ * $Id: bulletin_board_ui.c,v 1.134 2004/01/24 07:04:14 fuyu Exp $
  */
 
 #include "config.h"
@@ -1887,6 +1887,8 @@ static void
 advance_view_cb(ThreadlistView *view, OchushaBBSThread *thread,
 		PanedNotebook *paned_notebook)
 {
+  MAIN_THREAD_EVENT_CALLBACK();
+
   if (paned_notebook_get_current_item(paned_notebook) != thread)
     paned_notebook_open_item_view(paned_notebook, thread, FALSE, TRUE);
   else
@@ -1897,6 +1899,8 @@ advance_view_cb(ThreadlistView *view, OchushaBBSThread *thread,
       g_signal_emit_by_name(G_OBJECT(scrolled_window), "scroll_child",
 			    GTK_SCROLL_PAGE_FORWARD, FALSE);
     }
+
+  ENTER_MAIN_EVENT_LOOP();
 }
 
 
@@ -1904,6 +1908,8 @@ static void
 back_view_cb(ThreadlistView *view, OchushaBBSThread *thread,
 	     PanedNotebook *paned_notebook)
 {
+  MAIN_THREAD_EVENT_CALLBACK();
+
   if (paned_notebook_get_current_item(paned_notebook) != thread)
     paned_notebook_open_item_view(paned_notebook, thread, FALSE, TRUE);
   else
@@ -1914,6 +1920,8 @@ back_view_cb(ThreadlistView *view, OchushaBBSThread *thread,
       g_signal_emit_by_name(G_OBJECT(scrolled_window), "scroll_child",
 			    GTK_SCROLL_PAGE_BACKWARD, FALSE);
     }
+
+  ENTER_MAIN_EVENT_LOOP();
 }
 
 
@@ -1931,7 +1939,11 @@ write_response_cb(ThreadlistView *view, OchushaBBSThread *thread,
 static void
 close_threadlist_cb(ThreadlistView *view, OchushaApplication *application)
 {
+  MAIN_THREAD_EVENT_CALLBACK();
+
   paned_notebook_close_current_item_view(PANED_NOTEBOOK(application->contents_window));
+
+  ENTER_MAIN_EVENT_LOOP();
 }
 
 
@@ -1941,7 +1953,12 @@ toggle_mark_cb(ThreadlistView *view, OchushaBBSThread *thread,
 {
   BBSThreadGUIInfo *info = ensure_bbs_thread_info(thread);
   info->view_flags ^= BBS_THREAD_MARKED;
+
+  MAIN_THREAD_EVENT_CALLBACK();
+
   update_threadlist_entry_style(application, view, thread);
+
+  ENTER_MAIN_EVENT_LOOP();
 }
 
 
@@ -1951,7 +1968,12 @@ toggle_hide_cb(ThreadlistView *view, OchushaBBSThread *thread,
 {
   BBSThreadGUIInfo *info = ensure_bbs_thread_info(thread);
   info->view_flags ^= BBS_THREAD_HIDDEN;
+
+  MAIN_THREAD_EVENT_CALLBACK();
+
   update_threadlist_entry_style(application, view, thread);
+
+  ENTER_MAIN_EVENT_LOOP();
 }
 
 
@@ -1960,11 +1982,16 @@ reset_thread_cb(ThreadlistView *view, OchushaBBSThread *thread,
 		OchushaApplication *application)
 {
   BBSThreadGUIInfo *info = ensure_bbs_thread_info(thread);
+
+  MAIN_THREAD_EVENT_CALLBACK();
+
   ochusha_bbs_thread_remove_cache(thread, &application->config);
   info->view_flags = 0;
   info->bookmark_response_number = 0;
   update_threadlist_entry_style(application, view, thread);
   bookmark_remove_thread(application->all_threads, thread, application);
+
+  ENTER_MAIN_EVENT_LOOP();
 }
 
 
@@ -1973,11 +2000,19 @@ super_reset_thread_cb(ThreadlistView *view, OchushaBBSThread *thread,
 		      OchushaApplication *application)
 {
   BBSThreadGUIInfo *info = ensure_bbs_thread_info(thread);
-  ochusha_bbs_thread_remove_cache(thread, &application->config);
-  info->view_flags = 0;
-  info->bookmark_response_number = 0;
-  update_threadlist_entry_style(application, view, thread);
-  virtual_board_remove_thread(VIRTUAL_BOARD(application->all_threads), thread);
+
+  MAIN_THREAD_EVENT_CALLBACK();
+
+  if (virtual_board_remove_thread(VIRTUAL_BOARD(application->all_threads),
+				  thread))
+    {
+      ochusha_bbs_thread_remove_cache(thread, &application->config);
+      info->view_flags = 0;
+      info->bookmark_response_number = 0;
+      update_threadlist_entry_style(application, view, thread);
+    }
+
+  ENTER_MAIN_EVENT_LOOP();
 }
 
 
@@ -1985,7 +2020,11 @@ static void
 kill_thread_cb(ThreadlistView *view, OchushaBBSThread *thread,
 	       VirtualBoard *board)
 {
+  MAIN_THREAD_EVENT_CALLBACK();
+
   virtual_board_remove_thread(board, thread);
+
+  ENTER_MAIN_EVENT_LOOP();
 }
 
 
@@ -1994,10 +2033,18 @@ super_kill_thread_cb(ThreadlistView *view, OchushaBBSThread *thread,
 		     OchushaApplication *application)
 {
   BBSThreadGUIInfo *info = ensure_bbs_thread_info(thread);
-  ochusha_bbs_thread_remove_cache(thread, &application->config);
-  info->view_flags = 0;
-  info->bookmark_response_number = 0;
-  virtual_board_remove_thread(VIRTUAL_BOARD(application->all_threads), thread);
+
+  MAIN_THREAD_EVENT_CALLBACK();
+
+  if (virtual_board_remove_thread(VIRTUAL_BOARD(application->all_threads),
+				  thread))
+    {
+      ochusha_bbs_thread_remove_cache(thread, &application->config);
+      info->view_flags = 0;
+      info->bookmark_response_number = 0;
+    }
+
+  ENTER_MAIN_EVENT_LOOP();
 }
 
 
@@ -2005,7 +2052,11 @@ static void
 copy_thread_url_cb(ThreadlistView *view, OchushaBBSThread *thread,
 		   OchushaApplication *application)
 {
+  MAIN_THREAD_EVENT_CALLBACK();
+
   ochusha_clipboard_set_text(application, ochusha_bbs_thread_get_url(thread));
+
+  ENTER_MAIN_EVENT_LOOP();
 }
 
 
@@ -2087,7 +2138,8 @@ bookmark_remove_thread(OchushaBulletinBoard *board, OchushaBBSThread *thread,
   if (proxy == NULL)
     return;	/* Ѥ⤽äƤʤ */
 
-  virtual_board_remove_thread(VIRTUAL_BOARD(board), proxy);
+  if (!virtual_board_remove_thread(VIRTUAL_BOARD(board), proxy))
+    return;	/* ˻äƤɤʤ */
 
   widget = paned_notebook_get_item_view(PANED_NOTEBOOK(application->contents_window), board);
   if (widget != NULL)
@@ -2121,7 +2173,9 @@ mark_thread_cb(ThreadlistView *view, OchushaBBSThread *thread,
     info->view_flags |= BBS_THREAD_MARKED;
   else
     info->view_flags &= ~BBS_THREAD_MARKED;
+  MAIN_THREAD_EVENT_CALLBACK();
   update_threadlist_entry_style(application, view, thread);
+  ENTER_MAIN_EVENT_LOOP();
 }
 
 
@@ -2498,6 +2552,7 @@ page_switched_cb(PanedNotebook *paned_notebook,
   thread = paned_notebook_get_item(paned_notebook, new_page);
   if (scrolled_window == NULL || thread == NULL)
     {
+      ENTER_MAIN_EVENT_LOOP();
       return;
     }
 
