@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: main.c,v 1.25 2004/01/21 17:29:03 fuyu Exp $
+ * $Id: main.c,v 1.27 2004/01/25 16:34:39 fuyu Exp $
  */
 
 #include "config.h"
@@ -64,9 +64,35 @@
 pthread_t volatile last_lock_owner = NULL;
 volatile const char *last_file;
 volatile int last_line;
+#endif
+
+#if USE_THREAD_FOR_MAIN || DEBUG_GDK_LOCK
 pthread_t main_thread = NULL;
 #endif
 
+#if USE_THREAD_FOR_MAIN
+static void
+real_main(OchushaApplication *application)
+{
+  OCHU_THREADS_ENTER();
+
+  ENTER_MAIN_EVENT_LOOP();
+  gtk_main();
+
+#if TRACE_MEMORY_USAGE
+  if (application->top_level != NULL)
+    gtk_widget_destroy(GTK_WIDGET(application->top_level));
+#endif
+
+#if 1
+  MAIN_THREAD_EVENT_CALLBACK();	/* ä */
+  OCHU_THREADS_LEAVE();
+#else
+  gdk_threads_leave();
+#endif
+}
+#endif
+
 
 int
 main(int argc, char *argv[])
@@ -203,10 +229,6 @@ main(int argc, char *argv[])
   initialize_default_entity_dictionary();
   initialize_common_converters();
 
-#if DEBUG_GDK_LOCK
-  main_thread = pthread_self();
-#endif
-
   initialize_worker(INITIAL_NUM_THREADS, MAXIMUM_NUM_THREADS,
 		    MAXIMUM_NUM_MODEST_THREADS);
 
@@ -246,12 +268,30 @@ main(int argc, char *argv[])
 
   ochusha_init_application(application);
 
-#if 0	/* Ѥθå */
+#if ENABLE_STRICT_CHECK	/* Ѥθå */
   g_log_set_always_fatal(G_LOG_LEVEL_WARNING
 			 | G_LOG_LEVEL_CRITICAL
 			 | G_LOG_LEVEL_ERROR);
 #endif
 
+#if USE_THREAD_FOR_MAIN
+  if (pthread_create(&main_thread, NULL,
+		     (void *(*)(void *))real_main, application) != 0)
+    {
+      fprintf(stderr, "Couldn't start main thread.\n");
+      abort();
+    }
+
+  if (pthread_join(main_thread, NULL) != 0)
+    {
+      fprintf(stderr, "Couldn't join to main thread.\n");
+      abort();
+    }
+#else
+#if DEBUG_GDK_LOCK
+  main_thread = pthread_self();
+#endif
+
   OCHU_THREADS_ENTER();
 
   ENTER_MAIN_EVENT_LOOP();
@@ -267,8 +307,10 @@ main(int argc, char *argv[])
   OCHU_THREADS_LEAVE();
 #else
   gdk_threads_leave();
+#endif
 #endif
 
+  ochusha_network_broker_terminate(application->broker);
   terminate_workers();
   join_workers();
 
