@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_ui.h,v 1.68 2004/01/20 07:51:35 fuyu Exp $
+ * $Id: ochusha_ui.h,v 1.71 2004/01/27 11:57:24 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_UI_H_
@@ -52,6 +52,7 @@
 #define OCHUSHA_BOOKMARK_XML				"bookmark.xml.gz"
 #define OCHUSHA_SESSION_XML				"session.xml.gz"
 #define OCHUSHA_INIT_SCM				"ochusha-init.scm"
+#define OCHUSHA_A_BONE_IMAGE_TXT			"a-bone-image.txt"
 
 #define OCHUSHA_CURRENT_CONFIG_VERSION					2
 
@@ -187,6 +188,11 @@ struct _OchushaApplication
   OchushaBoardCategory *my_folder;
   OchushaBulletinBoard *favorites;
   OchushaBulletinBoard *all_threads;
+
+  gboolean thread_list_already_read;
+  GSList *favorites_list;
+  char *recently_added_favorites;
+
   OchushaBBSTable *table;
 
 
@@ -277,6 +283,8 @@ struct _OchushaApplication
   gboolean hide_hidden_threads;
 
   OchushaNetworkBroker *broker;
+  int download_chunksize;
+  int image_chunksize;
 
 
   /* Ǹν񤭹߻̾ */
