@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: session.c,v 1.12 2004/01/15 02:18:05 fuyu Exp $
+ * $Id: session.c,v 1.14 2004/01/24 07:04:14 fuyu Exp $
  */
 
 #include "config.h"
@@ -33,6 +33,7 @@
 
 #include "ochusha_ui.h"
 #include "boardlist_ui.h"
+#include "image_ui.h"
 #include "session.h"
 
 #include <glib.h>
@@ -93,6 +94,7 @@ ochusha_session_save_states(OchushaApplication *application)
   application->boardlist_width = allocation->width;
 
   finalize_boardlist(application);
+  finalize_image_ui(application);
 
   application->shutdown_succeeded = TRUE;
   ochusha_session_write_session_xml(application, application->session_subdir);
@@ -192,6 +194,9 @@ ochusha_session_write_session_xml(OchushaApplication *application,
   OUTPUT_SESSION_ATTRIBUTE_INT(session_xml, application, boardlist_width);
   OUTPUT_SESSION_ATTRIBUTE_INT(session_xml, application, threadlist_height);
 
+  OUTPUT_SESSION_ATTRIBUTE_STRING(session_xml, application,
+				  recently_added_favorites);
+
   OUTPUT_SESSION_ATTRIBUTE_INT(session_xml, application,
 			       threadlist_search_direction);
   OUTPUT_SESSION_ATTRIBUTE_BOOLEAN(session_xml, application,
@@ -546,6 +551,22 @@ ochusha_session_restore_states(OchushaApplication *application)
       application->threadlist_height
 	= ochusha_utils_get_attribute_int(attr, "threadlist_height");
 
+      if (application->recently_added_favorites != NULL)
+	{
+	  char *tmp_id = application->recently_added_favorites;
+	  application->recently_added_favorites
+	    = ochusha_utils_get_attribute_string(attr,
+						 "recently_added_favorites");
+	  if (application->recently_added_favorites == NULL)
+	    application->recently_added_favorites = tmp_id;
+	  else
+	    G_FREE(tmp_id);
+	}
+      else
+	application->recently_added_favorites
+	  = ochusha_utils_get_attribute_string(attr,
+					       "recently_added_favorites");
+
       application->threadlist_search_direction
 	= ochusha_utils_get_attribute_int(attr, "threadlist_search_direction");
       application->threadlist_search_enable_wrap
