@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: virtual_board.c,v 1.17 2004/01/22 07:46:38 fuyu Exp $
+ * $Id: virtual_board.c,v 1.18 2004/01/24 07:04:14 fuyu Exp $
  */
 
 #include "config.h"
@@ -198,14 +198,16 @@ update_board_list(gpointer list_data, gpointer user_data)
 }
 
 
-void
+gboolean
 virtual_board_remove_thread(VirtualBoard *virtual_board,
 			    OchushaBBSThread *thread)
 {
   OchushaBulletinBoard *board = (OchushaBulletinBoard *)virtual_board;
-  g_return_if_fail(IS_VIRTUAL_BOARD(virtual_board) && IS_THREAD_PROXY(thread));
+  g_return_val_if_fail(IS_VIRTUAL_BOARD(virtual_board)
+		       && IS_THREAD_PROXY(thread), FALSE);
 
-  ochusha_bulletin_board_lock_thread_list(board);
+  if (!ochusha_bulletin_board_trylock_thread_list(board))
+    return FALSE;
 
   if (g_hash_table_remove(board->thread_table, thread->id))
     {
@@ -218,6 +220,7 @@ virtual_board_remove_thread(VirtualBoard *virtual_board,
     }
 
   ochusha_bulletin_board_unlock_thread_list(board);
+  return TRUE;
 }
 
 
