@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: htmlutils.c,v 1.12 2004/01/14 09:59:48 fuyu Exp $
+ * $Id: htmlutils.c,v 1.13 2004/01/25 16:29:37 fuyu Exp $
  */
 
 #include "config.h"
@@ -472,8 +472,9 @@ parse_text_internal(ElementHandler *handler, void *context, const char *text,
       chr_len = (tmp_pos == NULL) ? rest_of_text : tmp_pos - cur_pos;
 
 #if ENABLE_FAKE_ANCHOR
-      if (fake_anchor && chr_len > 0)
+      if (fake_anchor && !handler->in_anchor && chr_len > 0)
 	{
+	  const char *tmp_url;
 	  const char *raw_url;
 	  /*
 	   * ޤcur_postmp_posδ֤ttp://õ
@@ -487,12 +488,38 @@ parse_text_internal(ElementHandler *handler, void *context, const char *text,
 	   * aǤ٤硢URLʬtmp_posۤ礬(URL
 	   * &ʤɤ)դɬס
 	   */
-	  raw_url = g_strstr_len(cur_pos, chr_len, "ttp://");
+	  raw_url = g_strstr_len(cur_pos, chr_len, "tp://");
 	  if (raw_url != NULL)
 	    {
-	      if (raw_url > cur_pos && raw_url[-1] == 'h')
-		raw_url--;	/* 1ʸ᤹ */
+	      if (raw_url > cur_pos && raw_url[-1] == 'f')
+		{
+		  raw_url--;	/* 1ʸ᤹ */
+		}
+	      else
+		{
+		  if (raw_url > cur_pos && raw_url[-1] == 't')
+		    raw_url--;	/* 1ʸ᤹ */
+		  if (raw_url > cur_pos && raw_url[-1] == 'h')
+		    raw_url--;	/* 1ʸ᤹ */
+		}
+	    }
 
+	  tmp_url = g_strstr_len(cur_pos, chr_len, "tps://");
+	  if (tmp_url != NULL)
+	    {
+	      if (tmp_url > cur_pos && tmp_url[-1] == 't')
+		tmp_url--;	/* 1ʸ᤹ */
+	      if (tmp_url > cur_pos && tmp_url[-1] == 'h')
+		tmp_url--;	/* 1ʸ᤹ */
+
+	      if (raw_url == NULL)
+		raw_url = tmp_url;
+	      else if (raw_url > tmp_url)
+		raw_url = tmp_url;
+	    }
+
+	  if (raw_url != NULL)
+	    {
 	      tmp_pos = raw_url;
 	      chr_len = (tmp_pos == NULL) ? rest_of_text : tmp_pos - cur_pos;
 	    }
@@ -657,6 +684,7 @@ parse_text_internal(ElementHandler *handler, void *context, const char *text,
 				       rest_of_text);
 	  break;
 
+	case 'f':
 	case 'h':
 	case 't':
 	  cur_pos = fake_anchor_tag(handler, context, tmp_pos, rest_of_text);
@@ -830,11 +858,15 @@ process_tag(ElementHandler *handler, void *context, const char *head, int len)
     {
       if (handler->endElement != NULL)
 	(*handler->endElement)(context, name);
+      if (g_ascii_strcasecmp(name, "a") == 0)
+	handler->in_anchor = FALSE;
     }
   else
     {
       if (handler->startElement != NULL)
 	(*handler->startElement)(context, name, (const char *const *)attrs);
+      if (g_ascii_strcasecmp(name, "a") == 0)
+	handler->in_anchor = TRUE;
     }
 
  finish:
@@ -973,20 +1005,58 @@ fake_anchor_tag(ElementHandler *handler, void *context, const char *head,
       NULL,
       NULL
     };
-  char url_buffer[PATH_MAX] = "http://";
-  int tmp_len;
-  int url_len;
+  char url_buffer[PATH_MAX];
+  size_t tmp_len;
+  size_t url_len;
+  const char *scheme = "http://";
+  size_t scheme_len = 7;
 
-  if (*head == 'h')
+  if (strncmp(head, "http://", 7) == 0)
     {
       cur_pos += 7;	/* skip "http://" */
       len -= 7;
     }
-  else
+  else if (strncmp(head, "ttp://", 6) == 0 || strncmp(head, "htp://", 6) == 0)
     {
-      cur_pos += 6;	/* skip "ttp://" */
+      cur_pos += 6;	/* skip "ttp://" or "htp://" */
       len -= 6;
     }
+  else if (strncmp(head, "tp://", 5) == 0)
+    {
+      cur_pos += 5;	/* skip "tp://" */
+      len -= 5;
+    }
+  else if (strncmp(head, "https://", 8) == 0)
+    {
+      cur_pos += 8;	/* skip "https://" */
+      len -= 8;
+      scheme = "https://";
+      scheme_len = 8;
+    }
+  else if (strncmp(head, "ttps://", 7) == 0
+	   || strncmp(head, "htps://", 7) == 0)
+    {
+      cur_pos += 7;	/* skip "ttps://" or "htps://" */
+      len -= 7;
+      scheme = "https://";
+      scheme_len = 8;
+    }
+  else if (strncmp(head, "tps://", 6) == 0)
+    {
+      cur_pos += 6;	/* skip "tps://" */
+      len -= 6;
+      scheme = "https://";
+      scheme_len = 8;
+    }
+  else if (strncmp(head, "ftp://", 6) == 0)
+    {
+      cur_pos += 6;	/* skip "ftp://" */
+      len -= 6;
+      scheme = "ftp://";
+      scheme_len = 6;
+    }
+  else
+    abort();	/* ꤨϤ */
 
 #if ENABLE_SKIP_IME_NU
   /*
@@ -1035,8 +1105,10 @@ fake_anchor_tag(ElementHandler *handler, void *context, const char *head,
   if (url_len > PATH_MAX - 7)
     return head + 2;	/* Ĺϥѥ(2ʸΤƤƥᥤ롼פⲽ) */
 
-  memcpy(url_buffer + 7, cur_pos, url_len);
-  url_buffer[url_len + 7] = '\0';
+  scheme_len = strlen(scheme);
+  memcpy(url_buffer, scheme, scheme_len);
+  memcpy(url_buffer + scheme_len, cur_pos, url_len);
+  url_buffer[url_len + scheme_len] = '\0';
 
 #if DEBUG_PARSER_MOST
   fprintf(stderr, "URL: \"%s\"\n", url_buffer);
