@@ -6,31 +6,7 @@
 
 G_BEGIN_DECLS
 
-/* BOOLEAN:OBJECT (marshal.list:1) */
-extern void libochusha_marshal_BOOLEAN__OBJECT (GClosure     *closure,
-                                                GValue       *return_value,
-                                                guint         n_param_values,
-                                                const GValue *param_values,
-                                                gpointer      invocation_hint,
-                                                gpointer      marshal_data);
-
-/* BOOLEAN:OBJECT,INT,INT (marshal.list:2) */
-extern void libochusha_marshal_BOOLEAN__OBJECT_INT_INT (GClosure     *closure,
-                                                        GValue       *return_value,
-                                                        guint         n_param_values,
-                                                        const GValue *param_values,
-                                                        gpointer      invocation_hint,
-                                                        gpointer      marshal_data);
-
-/* BOOLEAN:OBJECT,INT,STRING (marshal.list:3) */
-extern void libochusha_marshal_BOOLEAN__OBJECT_INT_STRING (GClosure     *closure,
-                                                           GValue       *return_value,
-                                                           guint         n_param_values,
-                                                           const GValue *param_values,
-                                                           gpointer      invocation_hint,
-                                                           gpointer      marshal_data);
-
-/* OBJECT:STRING (marshal.list:4) */
+/* OBJECT:STRING (marshal.list:1) */
 extern void libochusha_marshal_OBJECT__STRING (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
@@ -38,7 +14,7 @@ extern void libochusha_marshal_OBJECT__STRING (GClosure     *closure,
                                                gpointer      invocation_hint,
                                                gpointer      marshal_data);
 
-/* OBJECT:INT,STRING,STRING (marshal.list:5) */
+/* OBJECT:INT,STRING,STRING (marshal.list:2) */
 extern void libochusha_marshal_OBJECT__INT_STRING_STRING (GClosure     *closure,
                                                           GValue       *return_value,
                                                           guint         n_param_values,
@@ -46,16 +22,32 @@ extern void libochusha_marshal_OBJECT__INT_STRING_STRING (GClosure     *closure,
                                                           gpointer      invocation_hint,
                                                           gpointer      marshal_data);
 
-/* VOID:POINTER (marshal.list:6) */
+/* VOID:POINTER (marshal.list:3) */
 #define libochusha_marshal_VOID__POINTER	g_cclosure_marshal_VOID__POINTER
 
-/* VOID:STRING (marshal.list:7) */
+/* VOID:STRING (marshal.list:4) */
 #define libochusha_marshal_VOID__STRING	g_cclosure_marshal_VOID__STRING
 
-/* VOID:VOID (marshal.list:8) */
+/* VOID:VOID (marshal.list:5) */
 #define libochusha_marshal_VOID__VOID	g_cclosure_marshal_VOID__VOID
 
-/* VOID:OBJECT,POINTER (marshal.list:9) */
+/* VOID:INT,INT (marshal.list:6) */
+extern void libochusha_marshal_VOID__INT_INT (GClosure     *closure,
+                                              GValue       *return_value,
+                                              guint         n_param_values,
+                                              const GValue *param_values,
+                                              gpointer      invocation_hint,
+                                              gpointer      marshal_data);
+
+/* VOID:INT,STRING (marshal.list:7) */
+extern void libochusha_marshal_VOID__INT_STRING (GClosure     *closure,
+                                                 GValue       *return_value,
+                                                 guint         n_param_values,
+                                                 const GValue *param_values,
+                                                 gpointer      invocation_hint,
+                                                 gpointer      marshal_data);
+
+/* VOID:OBJECT,POINTER (marshal.list:8) */
 extern void libochusha_marshal_VOID__OBJECT_POINTER (GClosure     *closure,
                                                      GValue       *return_value,
                                                      guint         n_param_values,
