@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_async_buffer.c,v 1.27 2004/01/21 17:25:59 fuyu Exp $
+ * $Id: ochusha_async_buffer.c,v 1.30 2004/01/27 11:58:11 fuyu Exp $
  */
 
 #include "config.h"
@@ -623,8 +623,13 @@ ochusha_async_buffer_reset(OchushaAsyncBuffer *buffer)
 {
   g_return_val_if_fail(OCHUSHA_IS_ASYNC_BUFFER(buffer), FALSE);
   /* g_return_val_if_fail(buffer->number_of_active_users == 0, FALSE); */
+  LOCK_BUFFER_LOCK(buffer);
+
   buffer->fixed = FALSE;
   buffer->state = OCHUSHA_ASYNC_BUFFER_OK;
+  buffer->number_of_suspended_users = 0;
+
+  UNLOCK_BUFFER_LOCK(buffer);
   return TRUE;
 }
 
@@ -678,6 +683,11 @@ ochusha_async_buffer_active_ref(OchushaAsyncBuffer *buffer)
   if (!result)
     {
       buffer->number_of_active_users--;
+
+      LOCK_GLOBAL_LOCK;
+      SIGNAL_GLOBAL_CONDITION;
+      UNLOCK_GLOBAL_LOCK;
+
       g_object_unref(G_OBJECT(buffer));	/* Ĵ٤Ƥʤ */
     }
 
@@ -843,8 +853,6 @@ ochusha_async_buffer_terminate(OchushaAsyncBuffer *buffer)
 		async_buffer_signals[WAKEUP_NOW_SIGNAL],
 		0);
 
-  UNLOCK_BUFFER_LOCK(buffer);
-
 #if DEBUG_OCHUSHA_ASYNC_BUFFER_MOST
   fprintf(stderr,
 	  "ochusha_async_buffer_terminate: buffer lock unlocked\n");
@@ -852,13 +860,17 @@ ochusha_async_buffer_terminate(OchushaAsyncBuffer *buffer)
 
   while (buffer->number_of_active_users > 0)
     {
+      UNLOCK_BUFFER_LOCK(buffer);
 #if DEBUG_OCHUSHA_ASYNC_BUFFER_MOST
       fprintf(stderr,
 	      "ochusha_async_buffer_terminate: active_users=%d\n",
 	      buffer->number_of_active_users);
 #endif
       WAIT_GLOBAL_CONDITION;
+      LOCK_BUFFER_LOCK(buffer);
     }
+  UNLOCK_BUFFER_LOCK(buffer);
+
 #if DEBUG_OCHUSHA_ASYNC_BUFFER_MOST
   fprintf(stderr, "ochusha_async_buffer_terminate: active_users=%d\n",
 	  buffer->number_of_active_users);
@@ -1284,3 +1296,42 @@ ochusha_async_buffer_free_when_finished(OchushaAsyncBuffer *buffer)
   if (buffer->buffer != NULL)
     G_FREE((void *)buffer->buffer);
 }
+
+
+void
+ochusha_async_buffer_emit_access_started(OchushaAsyncBuffer *buffer)
+{
+  g_return_if_fail(OCHUSHA_IS_ASYNC_BUFFER(buffer));
+  g_signal_emit(G_OBJECT(buffer),
+		async_buffer_signals[ACCESS_STARTED_SIGNAL], 0);
+}
+
+
+void
+ochusha_async_buffer_emit_access_progressed(OchushaAsyncBuffer *buffer,
+					    int bytes_read, int bytes_total)
+{
+  g_return_if_fail(OCHUSHA_IS_ASYNC_BUFFER(buffer));
+  g_signal_emit(G_OBJECT(buffer),
+		async_buffer_signals[ACCESS_PROGRESSED_SIGNAL], 0,
+		bytes_read, bytes_total);
+}
+
+
+void
+ochusha_async_buffer_emit_access_finished(OchushaAsyncBuffer *buffer)
+{
+  g_return_if_fail(OCHUSHA_IS_ASYNC_BUFFER(buffer));
+  g_signal_emit(G_OBJECT(buffer),
+		async_buffer_signals[ACCESS_FINISHED_SIGNAL], 0);
+}
+
+
+void
+ochusha_async_buffer_emit_access_failed(OchushaAsyncBuffer *buffer,
+					int reason_code, const gchar *reason)
+{
+  g_return_if_fail(OCHUSHA_IS_ASYNC_BUFFER(buffer));
+  g_signal_emit(G_OBJECT(buffer),
+		async_buffer_signals[ACCESS_FAILED_SIGNAL], 0);
+}
