@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_board_jbbs.c,v 1.13 2004/01/21 08:41:01 fuyu Exp $
+ * $Id: ochusha_board_jbbs.c,v 1.15 2004/01/27 11:58:11 fuyu Exp $
  */
 
 #include "config.h"
@@ -53,7 +53,7 @@
 #include <unistd.h>
 
 
-#define ANALYSIS_INTERVAL	200
+#define ANALYSIS_INTERVAL	50
 
 
 static void ochusha_board_jbbs_class_init(OchushaBoardJBBSClass *klass);
@@ -624,8 +624,9 @@ ochusha_board_jbbs_get_threadlist_source(OchushaBulletinBoard *board,
   board_2ch = OCHUSHA_BOARD_2CH(board);
 
   return ochusha_network_broker_read_from_url(broker, buffer, url,
-					      board_2ch->last_modified, mode,
-					      FALSE);
+					board_2ch->last_modified, mode,
+					FALSE,
+					broker->config->threadlist_chunksize);
 }
 
 
@@ -767,6 +768,7 @@ refresh_threadlist_by_subject_txt(OchushaBulletinBoard *board,
   {
     unsigned int offset = 0;
     gboolean buffer_fixed = FALSE;
+    int interval = ANALYSIS_INTERVAL;
 
     if (start_parsing_cb != NULL)
       (*start_parsing_cb)(callback_data);
@@ -777,7 +779,6 @@ refresh_threadlist_by_subject_txt(OchushaBulletinBoard *board,
 	char *cur_pos = buffer_top + offset;
 	unsigned int rest_of_data = buffer->length - offset;
 	char *eol_pos = NULL;
-	int interval = ANALYSIS_INTERVAL;
 
 	while (rest_of_data > 0
 	       && interval-- > 0
@@ -919,8 +920,13 @@ refresh_threadlist_by_subject_txt(OchushaBulletinBoard *board,
 	  {
 	    OCHU_OBJECT_REF(buffer);
 	    g_object_set_qdata(G_OBJECT(buffer), idle_checker_id, buffer);
+#if 0
 	    g_idle_add_full(G_PRIORITY_HIGH_IDLE + 30,
 			    advance_parsing, buffer, NULL);
+#else
+	    g_idle_add_full(G_PRIORITY_HIGH_IDLE + 15,
+			    advance_parsing, buffer, NULL);
+#endif
 	    if (before_wait_cb != NULL)
 	      (*before_wait_cb)(callback_data);
 	    do
@@ -935,8 +941,8 @@ refresh_threadlist_by_subject_txt(OchushaBulletinBoard *board,
 					  idle_checker_id) != NULL);
 	    if (after_wait_cb != NULL)
 	      (*after_wait_cb)(callback_data);
+	    interval = ANALYSIS_INTERVAL;
 	  }
-	interval = ANALYSIS_INTERVAL;
 
 	if (status->state == OCHUSHA_NETWORK_BROKER_BUFFER_STATE_CACHE_IS_DIRTY)
 	  {
@@ -1198,7 +1204,7 @@ refresh_threadlist_by_subback_html(OchushaBulletinBoard *board,
 	  {
 	    OCHU_OBJECT_REF(buffer);
 	    g_object_set_qdata(G_OBJECT(buffer), idle_checker_id, buffer);
-	    g_idle_add_full(G_PRIORITY_HIGH_IDLE + 30,
+	    g_idle_add_full(G_PRIORITY_HIGH_IDLE + 15,
 			    advance_parsing, buffer, NULL);
 	    if (before_wait_cb != NULL)
 	      (*before_wait_cb)(callback_data);
@@ -1214,8 +1220,8 @@ refresh_threadlist_by_subback_html(OchushaBulletinBoard *board,
 					  idle_checker_id) != NULL);
 	    if (after_wait_cb != NULL)
 	      (*after_wait_cb)(callback_data);
+	    interval = ANALYSIS_INTERVAL;
 	  }
-	interval = ANALYSIS_INTERVAL;
 
 	if (status->state == OCHUSHA_NETWORK_BROKER_BUFFER_STATE_CACHE_IS_DIRTY)
 	  {
