@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_bulletin_board.c,v 1.32 2004/01/18 04:50:26 fuyu Exp $
+ * $Id: ochusha_bulletin_board.c,v 1.33 2004/01/24 07:02:35 fuyu Exp $
  */
 
 #include "config.h"
@@ -553,6 +553,29 @@ ochusha_bulletin_board_lock_thread_list(OchushaBulletinBoard *board)
 }
 
 
+gboolean
+ochusha_bulletin_board_trylock_thread_list(OchushaBulletinBoard *board)
+{
+  g_assert(OCHUSHA_IS_BULLETIN_BOARD(board));
+
+  if (pthread_mutex_trylock(&board->thread_list_lock) != 0)
+    return FALSE;
+
+  if (board->is_busy)
+    {
+      if (pthread_mutex_unlock(&board->thread_list_lock) != 0)
+	{
+	  fprintf(stderr, "Couldn't unlock a mutex.\n");
+	  abort();
+	}
+      return FALSE;
+    }
+
+  board->is_busy = TRUE;
+  return TRUE;
+}
+
+
 void
 ochusha_bulletin_board_unlock_thread_list(OchushaBulletinBoard *board)
 {
