@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_config.c,v 1.26 2004/01/17 09:28:17 fuyu Exp $
+ * $Id: ochusha_config.c,v 1.27 2004/01/27 11:58:11 fuyu Exp $
  */
 
 #include "config.h"
@@ -987,6 +987,9 @@ ochusha_write_config_xml(OchushaConfig *config, const char *subdir,
   if (config->proxy_password == empty_string)
     config->proxy_password = NULL;
 
+  OUTPUT_CONFIG_ATTRIBUTE_INT(config_xml, config, threadlist_chunksize);
+  OUTPUT_CONFIG_ATTRIBUTE_INT(config_xml, config, thread_chunksize);
+
   if (optional != NULL)
     (*optional)(config_xml, user_data);
   else
@@ -1086,6 +1089,19 @@ ochusha_read_config_xml(OchushaConfig *config, const char *subdir,
       if (config->proxy_password == NULL)
 	config->proxy_password = G_STRDUP("");
 
+      config->threadlist_chunksize
+	= ochusha_utils_get_attribute_int(pref, "threadlist_chunksize");
+
+      if (config->threadlist_chunksize == 0)
+	config->threadlist_chunksize = 4096;
+
+      config->thread_chunksize
+	= ochusha_utils_get_attribute_int(pref, "thread_chunksize");
+
+      if (config->thread_chunksize == 0)
+	config->thread_chunksize = 4096;
+
+
       if (optional != NULL)
 	(*optional)(pref, user_data);
       else
