@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_thread_2ch.c,v 1.63 2004/01/21 08:41:01 fuyu Exp $
+ * $Id: ochusha_thread_2ch.c,v 1.64 2004/01/27 11:58:11 fuyu Exp $
  */
 
 #include "config.h"
@@ -561,7 +561,8 @@ ochusha_thread_2ch_get_responses_source(OchushaBBSThread *thread,
 
   return ochusha_network_broker_read_from_url(broker, buffer,
 				ochusha_thread_2ch_get_dat_url(thread_2ch),
-				thread_2ch->last_modified, mode, FALSE);
+				thread_2ch->last_modified, mode, FALSE,
+				broker->config->thread_chunksize);
 }
 
 
